# Changelog

## [0.1.3](https://github.com/koesterlab/pubgator/compare/v0.1.2...v0.1.3) (2025-12-11)


### Miscellaneous Chores

* release 0.1.3 ([8224daf](https://github.com/koesterlab/pubgator/commit/8224daf3bd5b4186e75ce2c6d16052d6a5c415ef))

## [0.1.2](https://github.com/koesterlab/pubgator/compare/v0.1.1...v0.1.2) (2025-12-11)


### Miscellaneous Chores

* release 0.1.2 ([5861034](https://github.com/koesterlab/pubgator/commit/5861034d7c01bd4749a00def24bc39888459f5ad))

## [0.1.1](https://github.com/koesterlab/pubgator/compare/v0.1.0...v0.1.1) (2025-12-11)


### Miscellaneous Chores

* release 0.1.1 ([dc14ce5](https://github.com/koesterlab/pubgator/commit/dc14ce58466d141e513a7569b88084d03de3a881))

## 0.1.0 (2025-12-11)


### Features

* Initialize PubGator package with PubTator3 API client ([910f2e5](https://github.com/koesterlab/pubgator/commit/910f2e517e86c85a393e839ca9bd8a93a2498e08))


### Documentation

* Add usage example, license, and authors to README ([17f5d83](https://github.com/koesterlab/pubgator/commit/17f5d83d75c4e9871241023189557f33b7305b78))
* Update author email in pyproject.toml ([d48e652](https://github.com/koesterlab/pubgator/commit/d48e652c7b373931eb655bc31d163e2c5fc77193))
* Update autocomplete example to iterate results ([19fee99](https://github.com/koesterlab/pubgator/commit/19fee99c4b0610d4fff42182c8cb9237e827d87e))
* Use full author name in pyproject.toml ([93558bb](https://github.com/koesterlab/pubgator/commit/93558bbbef8336d9c9a0e6c260941789d7214ebc))
